@@ -1,7 +1,7 @@
 from .DistanceMatrix import DistanceMatrix
-from .Snapshots import Snapshots
 from .TemporalData import TemporalData
-from .TemporalNetwork import TemporalNetwork
+from .TemporalNetwork import TemporalNetwork, _process_input_tedges
+from .PartiallyTemporalNetwork import PartiallyTemporalNetwork
 
 # Make certain subpackages available to the user as direct imports from
 # the `phasik` namespace.
